searchData={"items":[{"type":"module","title":"IsabelleClientMini","doc":"**Minimalistic stateless Elixir client for the Isabelle Server**\n\nThis module wraps the Isabelle Server command‑line tools (`isabelle server`,\n`isabelle client`) and its TCP protocol (see *Isabelle System Manual*,\nChapter 4 under https://isabelle.in.tum.de/doc/system.pdf) in a set of\nsynchronous helper functions that remain completely stateless. You can use\nthese to spin up a resident server, connect to it, fire high‑level\ncommands (`session_start`, `use_theories`, …) and consume the streamed\nresults without having to parse the Isabelle wire protocol yourself.","ref":"IsabelleClientMini.html"},{"type":"module","title":"Typical lifecycle - IsabelleClientMini","doc":"1. (optionally) **Start** a resident server with `new_server/2` (or reuse\n   an existing one found via `list_servers/0`). Both commands require a\n   local Isabelle installation whose *`bin/`* directory is on the `PATH`.\n2. **Connect** using the password/token reported by the server (`connect/3`).\n   The corresponding Isabelle server only needs to be accessible via TCP.\n3. **Launch** a session once per logic image (`start_session/2`).\n4. **Edit/compile** theories with `use_theories/2`, polling for\n   `FINISHED | FAILED | NOTE` messages via `poll_status/2`.\n5. **Extract** results or artefacts with helpers such as `extract_results/1`.\n6. **Stop** the session (`stop_session/2`).\n7. (optionally) **Shutdown** the server (`shutdown_server/1`).\n   If running Isabelle locally you can alternatively use `kill_server/1`.","ref":"IsabelleClientMini.html#module-typical-lifecycle"},{"type":"module","title":"Caveats - IsabelleClientMini","doc":"* The client is intentionally **stateless** — it does **not** keep\n  supervision trees, reconnect, or monitor server liveness for you.  Compose\n  it inside your own supervision strategy if you need robustness.\n* Network I/O is done via `:gen_tcp` in passive mode; all helpers block the\n  calling process.  For high‑latency sessions consider running them inside\n  a dedicated Task or GenServer.","ref":"IsabelleClientMini.html#module-caveats"},{"type":"function","title":"IsabelleClientMini.build_session/2","doc":"Build session images (wrapper around `session_build`).","ref":"IsabelleClientMini.html#build_session/2"},{"type":"function","title":"IsabelleClientMini.cancel_task/2","doc":"Cancel a running asynchronous *task* (identified by its UUID).","ref":"IsabelleClientMini.html#cancel_task/2"},{"type":"function","title":"IsabelleClientMini.close/1","doc":"Close a previously opened TCP connection.","ref":"IsabelleClientMini.html#close/1"},{"type":"function","title":"IsabelleClientMini.connect/3","doc":"Open a TCP connection to an Isabelle server and perform the initial password\nhandshake.","ref":"IsabelleClientMini.html#connect/3"},{"type":"function","title":"Parameters - IsabelleClientMini.connect/3","doc":"* `password` – token obtained from the server descriptor (returned by\n  `new_server/2` or `list_servers/0` if running locally).\n* `host` – IPv4 address as string (default `127.0.0.1`).\n* `port` – TCP port (default `9999`).","ref":"IsabelleClientMini.html#connect/3-parameters"},{"type":"function","title":"Return value - IsabelleClientMini.connect/3","doc":"* `socket` – a live socket ready for further commands.\n* `{:error, reason}` on connection failures.","ref":"IsabelleClientMini.html#connect/3-return-value"},{"type":"function","title":"IsabelleClientMini.echo/2","doc":"Round‑trip test helper that sends `echo  ` and returns the decoded value.\nUseful for verifying the connection.","ref":"IsabelleClientMini.html#echo/2"},{"type":"function","title":"IsabelleClientMini.extract_results/1","doc":"Extract the plain‑text messages from a `:finished` status keyword list.","ref":"IsabelleClientMini.html#extract_results/1"},{"type":"function","title":"IsabelleClientMini.extract_session/1","doc":"Grab the `session_id` UUID from a `:finished` status keyword list.","ref":"IsabelleClientMini.html#extract_session/1"},{"type":"function","title":"IsabelleClientMini.help/1","doc":"Return the list of command names supported by the server (`help`).","ref":"IsabelleClientMini.html#help/1"},{"type":"function","title":"IsabelleClientMini.kill_server/1","doc":"Force‑terminate a named Isabelle server **process** via the CLI\n(`isabelle server -n   -x`). In case you really want to kill the Isabelle server,\n you can use this as a last resort if a clean `shutdown` over the TCP protocol is impossible.","ref":"IsabelleClientMini.html#kill_server/1"},{"type":"function","title":"IsabelleClientMini.list_servers/0","doc":"List **all locally running Isabelle servers**. Under the hood this simply invokes\n`isabelle server -l` and parses its stdout. Same caveat apply as with `new_server/2`.","ref":"IsabelleClientMini.html#list_servers/0"},{"type":"function","title":"IsabelleClientMini.new_server/2","doc":"Spawn a **resident Isabelle Server** in the background.\n\nThe function runs `isabelle server -n   -p  ` via an Erlang port,\nwaits for its first line of output, parses the server descriptor and then\ncloses the port (leaving the JVM process running detached).\nNote that if you want to start (and list) Isabelle servers programmatically\n(via the functions: new_server and list_servers) you have to make sure\nthat the \"bin\" directory in your Isabelle installation is in the PATH.","ref":"IsabelleClientMini.html#new_server/2"},{"type":"function","title":"Parameters - IsabelleClientMini.new_server/2","doc":"* `name` – arbitrary label used to identify the server in `list_servers/0`.\n  Defaults to `\"elixir\"`.\n* `port` – TCP port on which the server accepts connections. Defaults to\n  `9999`.","ref":"IsabelleClientMini.html#new_server/2-parameters"},{"type":"function","title":"Return value - IsabelleClientMini.new_server/2","doc":"`[%{\"name\" => name, \"host\" => host, \"port\" => port, \"password\" => pw}]` on\nsuccess, or `{:error, reason}` on failure / timeout.","ref":"IsabelleClientMini.html#new_server/2-return-value"},{"type":"function","title":"IsabelleClientMini.poll_status/2","doc":"Recursively poll the socket until the server finishes an async task.\n\nThe function returns **immediately** when it encounters one of the following\nconditions in the buffered stream:\n\n* `{:finished, ...}` – successful result (see `extract_results/1`).\n* `{:failed, ...}`   – task failed.\n* `{:error, reason}` – protocol mismatch / time‑out / empty buffer.\n\nInternally it keeps a growing accumulator so you don't lose any partial\nchunks.","ref":"IsabelleClientMini.html#poll_status/2"},{"type":"function","title":"IsabelleClientMini.purge_theories/2","doc":"Purge theories from heap to reclaim memory (`purge_theories`).","ref":"IsabelleClientMini.html#purge_theories/2"},{"type":"function","title":"IsabelleClientMini.shutdown_server/1","doc":"Send a `shutdown` command over the given socket, causing the **server\nprocess itself** to exit (all connected sessions will be dropped).","ref":"IsabelleClientMini.html#shutdown_server/1"},{"type":"function","title":"IsabelleClientMini.start_session/2","doc":"Start an Isabelle PIDE session, implicitly building images if needed.","ref":"IsabelleClientMini.html#start_session/2"},{"type":"function","title":"IsabelleClientMini.stop_session/2","doc":"Gracefully stop a running session (`session_stop`).","ref":"IsabelleClientMini.html#stop_session/2"},{"type":"function","title":"IsabelleClientMini.use_theories/2","doc":"Load / re‑load theories into the session (`use_theories`).","ref":"IsabelleClientMini.html#use_theories/2"},{"type":"extras","title":"Isabelle Elixir bindings and more","doc":"# Isabelle Elixir bindings and more\n\n[![Hex version](https://img.shields.io/hexpm/v/isabelle_elixir.svg)](https://hex.pm/packages/isabelle_elixir)\n[![HexDocs](https://img.shields.io/badge/hex-docs-brightgreen.svg)](https://hexdocs.pm/isabelle_elixir)\n\n> **Elixir bindings and utilities for the [Isabelle](https://isabelle.in.tum.de) proof assistant**\n\n`isabelle_elixir` lets you drive Isabelle’s *resident server* from Elixir code: start/stop the JVM server, launch logic sessions, compile & check theories, stream build progress, and retrieve generated artefacts – all with familiar Elixir APIs.\n\n---","ref":"readme.html"},{"type":"extras","title":"✨ Features - Isabelle Elixir bindings and more","doc":"* **Zero-pain server control** – start, list, kill Isabelle servers programmatically.  \n* **TCP client** – synchronous helpers for every core server command (`session_start`, `use_theories`, …).  \n* **Streaming status** – follow `NOTE`/`FINISHED`/`FAILED` messages and extract results.  \n* **Stateless by design** – works in scripts, Mix tasks, GenServers or LiveBooks.  \n* **Pure Elixir** – no NIFs.  \n\n---","ref":"readme.html#features"},{"type":"extras","title":"📦 Installation - Isabelle Elixir bindings and more","doc":"Add the dependency to your `mix.exs` and fetch it:\n\n```elixir\ndefp deps do\n  [\n    {:isabelle_elixir, \"~> 0.1\"}\n  ]\nend","ref":"readme.html#installation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}